//------------------------------------------------------------
//    mjframe
//------------------------------------------------------------
#include "../v/mjframe.h"
#include "../m/tmajan.h"
#include "../main.h"
#include <string>
#include <wx/wx.h>
#include <wx/image.h>

//------------------------------------------------------------
//    constructor
//------------------------------------------------------------
mjFrame::mjFrame(wxWindow* parent, int id,
		const wxString& title, const wxPoint& pos,
		const wxSize& size, long style):
    wxFrame(parent, id, title, pos, size, style)
{
	panel_1 = new wxPanel(this, panel_id);
	button_1 = new wxButton(this, restart_button_id, wxT("RESTART"));
	button_2 = new wxButton(this, agari_button_id, wxT(""));
	button_3 = new wxButton(this, wxID_ANY, wxT(""));
	frame_1_menubar = new wxMenuBar();
	wxMenu* menu_1 = new wxMenu();
	menu_1->Append(wxID_ANY, wxT("item"), wxEmptyString, wxITEM_NORMAL);
	frame_1_menubar->Append(menu_1, wxT("file"));
	SetMenuBar(frame_1_menubar);
	set_properties();
	do_layout();
}

//------------------------------------------------------------
//    set_properties
//------------------------------------------------------------
void mjFrame::set_properties()
{
    SetTitle(wxT("tMajan"));
    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
    SetBackgroundStyle(wxBG_STYLE_CUSTOM);
    panel_1->SetMinSize(wxSize(framesize[0], framesize[1]));
    panel_1->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_3DFACE));
}

//------------------------------------------------------------
//    do_layout
//------------------------------------------------------------
void mjFrame::do_layout()
{
    wxBoxSizer* sizer_1 = new wxBoxSizer(wxVERTICAL);
    wxBoxSizer* sizer_2 = new wxBoxSizer(wxHORIZONTAL);
    sizer_1->Add(panel_1, 1, wxEXPAND, 0);
    sizer_2->Add(button_2, 0, 0, 0);
    sizer_2->Add(button_3, 0, 0, 0);
    sizer_2->Add(button_1, 0, 0, 0);
    sizer_1->Add(sizer_2, 0, wxALIGN_RIGHT, 0);
    SetSizer(sizer_1);
    sizer_1->Fit(this);
    Layout();
}

//------------------------------------------------------------
//    void mjFrame::set_tMajan(tMajan *tmj1)
//------------------------------------------------------------
void mjFrame::set_tMajan(tMajan *tmj1)
{
	majan_1 = tmj1;
}


//------------------------------------------------------------
//    set_pai_images
//------------------------------------------------------------
void mjFrame::set_pai_images()
{
	int i1;
	std::string filename;
	wxImage img;
	for(i1 = 0; i1 < 34; i1++){
		filename = majan_1->Pais[i1].get_name();
		filename = "haiga/" + filename + ".gif";
		img.LoadFile(wxString(filename.c_str(), wxConvLocal));
		pai_images[i1] = wxBitmap(img, -1);
	}
	img.LoadFile(wxT("haiga/ura.gif"));
	pai_images[34] = wxBitmap(img, -1);
}
//------------------------------------------------------------
//    images_init
//------------------------------------------------------------
void mjFrame::images_init()
{
	wxColour c1(base_colour[0],
		base_colour[1], base_colour[2]);
	wxPen pen1(*wxTRANSPARENT_PEN);
	wxBrush br1(c1, wxSOLID);
	wxMemoryDC *dc1;
	
	main_img = wxBitmap(framesize[0], framesize[1]);
	dc1 = new wxMemoryDC(main_img);
	dc1->SetPen(pen1);
    dc1->SetBrush(br1);
	dc1->DrawRectangle(0, 0, framesize[0], framesize[1]);
	delete dc1;
	
	draw_dora_image();
}

//------------------------------------------------------------
//    update_tehai_image
//------------------------------------------------------------
void mjFrame::update_tehai_image()
{
	int i1, x0, v0[13];
	wxBitmap b1;
	wxMemoryDC *dc1 = new wxMemoryDC(main_img), *mDC;
	
	majan_1->seki_1->get(v0);
	
	for(i1 = 0; i1 < 13; i1++){
		x0 = tehai_pos[0] + i1 * pai_size[0];
		mDC = new wxMemoryDC(pai_images[(v0[i1])]);
		dc1->Blit(x0, tehai_pos[1], pai_size[0], pai_size[1],
			mDC, 0, 0, wxCOPY, true);
		delete mDC;
	}
	delete dc1;
}

//------------------------------------------------------------
//    mjframe::update_tumo_image()
//------------------------------------------------------------
void mjFrame::update_tumo_image()
{
	int i1, x0, v0;
	wxMemoryDC *dc1 = new wxMemoryDC(main_img), *mDC;
	
	v0 = majan_1->seki_1->get_tumo_hai();
	if(v0>-1){
		mDC = new wxMemoryDC(pai_images[v0]);
		dc1->Blit(tumo_pos[0], tumo_pos[1], pai_size[0], pai_size[1],
			mDC, 0, 0, wxCOPY, true);
		delete mDC;
	}else{
		wxColour c1(base_colour[0],
			base_colour[1], base_colour[2]);
		wxPen pen1(*wxTRANSPARENT_PEN);
		wxBrush br1(c1, wxSOLID);
		dc1->SetPen(pen1);
		dc1->SetBrush(br1);
		dc1->DrawRectangle(tumo_pos[0], tumo_pos[1],
			pai_size[0], pai_size[1]);
	}
	delete dc1;
}

//------------------------------------------------------------
//    mjframe::update_sutehai_image()
//------------------------------------------------------------
void mjFrame::update_sutehai_image()
{
	int x, y, w, h, m, n, j, r, v0;
	wxMemoryDC *dc = new wxMemoryDC(main_img);
	wxMemoryDC *mDC;
	
	j = majan_1->seki_1->get_junme() - 1;
	if(j<0) return;
	
	r = majan_1->seki_1->get_reach();
	v0 = majan_1->seki_1->get_kawa_hai(j);
	
	m = (j % 6);
	n = (r % 6);
	if(j==r){
		wxBitmap b1;
		wxImage img;
		b1 = pai_images[v0];
		img = b1.ConvertToImage();
		img.Rotate90(false);
		b1 = wxBitmap(img, -1);
		mDC = new wxMemoryDC(b1);
		x = m * pai_size[0];
		y = (int(m / 6)) * pai_size[1]
			+ (pai_size[1] - pai_size[0]);
		w = pai_size[1];
		h = pai_size[0];
	}else if((r<j)&&(m==n)){
		x = m * pai_size[0]
			+ (pai_size[1] - pai_size[0]);
		y = (int(j / 6)) * pai_size[1];
		w = pai_size[0];
		h = pai_size[1];
		mDC = new wxMemoryDC(pai_images[v0]);
	}else{
		x = m * pai_size[0];
		y = (int(j / 6)) * pai_size[1];
		w = pai_size[0];
		h = pai_size[1];
		mDC = new wxMemoryDC(pai_images[v0]);
	}
	dc->Blit(x + sute_pos[0], y + sute_pos[1],
		w, h, mDC, 0, 0, wxCOPY, true);
	delete mDC;
	delete dc;
}


void mjFrame::draw_dora_image()
{
	int i1, x0, v0;
	wxMemoryDC *dc1 = new wxMemoryDC(main_img), *mDC;
	
	mDC = new wxMemoryDC(pai_images[34]);
	for(i1 = 0; i1 < 7; i1++){
		if(i1!=2){
			x0 = dora_pos[0] + i1 * pai_size[0];
			dc1->Blit(x0, dora_pos[1], pai_size[0], pai_size[1],
				mDC, 0, 0, wxCOPY, true);
		}
	}
	delete mDC;
	v0 = majan_1->get_yama_hai(130);
	x0 = dora_pos[0] + 2 * pai_size[0];
	mDC = new wxMemoryDC(pai_images[v0]);
	dc1->Blit(x0, dora_pos[1], pai_size[0], pai_size[1],
		mDC, 0, 0, wxCOPY, true);
	delete mDC;
	delete dc1;
}

void mjFrame::draw_images()
{
	update_tehai_image();
	update_tumo_image();
	update_sutehai_image();
	wxPaintDC *dc1 = new wxPaintDC(panel_1);
	wxMemoryDC *mDC = new wxMemoryDC(main_img);
	
	dc1->Blit(0, 0, framesize[0], framesize[1], mDC, 0, 0);
	delete mDC;
	delete dc1;
}

